==> libreoffice-still-sdk-24.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.js <==
var servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet =
[
    [ "ResultSet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a7bbfca82bcfc46707d18119609fbeb14", null ],
    [ "XColumnLocate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a3ab7c5de117d58ea69c6cbe5881c86b1", null ],
    [ "XParameters", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a8dbcc3ecbdbb50232d68735cf27b7cb6", null ],
    [ "XRowSet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a245d2e3838b49a8d74cf8d90f4b6bd77", null ],
    [ "Command", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a70272cc3797fc39c8a694c651bef53ef", null ],
    [ "DataSourceName", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#ae32b88b27240268a6a5a2fecca03e1df", null ],
    [ "EscapeProcessing", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#aa71981b851337d3842caede42c842c31", null ],
    [ "MaxFieldSize", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#aeb490fbed057c9e1e5a8923401261e76", null ],
    [ "MaxRows", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a775f6ffcc0c191c81906a2c46bb6b0f3", null ],
    [ "Password", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a9c7aae3a8518d5efd22e991b5944e0d4", null ],
    [ "QueryTimeOut", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a969c52e3b4011e05d33bf95f4035a5ba", null ],
    [ "ResultSetType", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a20f37658bb98643b426f7d7f2e440ccb", null ],
    [ "TransactionIsolation", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#ac92e8f3d99b02aa161d980ee61989889", null ],
    [ "TypeMap", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a2254afb5b7c7542ed4be824bf2daa647", null ],
    [ "URL", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#af82bacfe5b6faf0534ae06a9540cb886", null ],
    [ "User", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a9f8df451a16165b0cf243e37bf9c6b62", null ]
];

==> libreoffice-still-sdk-25.2.7-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.js <==
var servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet =
[
    [ "com::sun::star::sdbc::ResultSet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a7bbfca82bcfc46707d18119609fbeb14", null ],
    [ "XColumnLocate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a3ab7c5de117d58ea69c6cbe5881c86b1", null ],
    [ "XParameters", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a8dbcc3ecbdbb50232d68735cf27b7cb6", null ],
    [ "XRowSet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a245d2e3838b49a8d74cf8d90f4b6bd77", null ],
    [ "Command", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a70272cc3797fc39c8a694c651bef53ef", null ],
    [ "DataSourceName", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#ae32b88b27240268a6a5a2fecca03e1df", null ],
    [ "EscapeProcessing", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#aa71981b851337d3842caede42c842c31", null ],
    [ "MaxFieldSize", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#aeb490fbed057c9e1e5a8923401261e76", null ],
    [ "MaxRows", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a775f6ffcc0c191c81906a2c46bb6b0f3", null ],
    [ "Password", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a9c7aae3a8518d5efd22e991b5944e0d4", null ],
    [ "QueryTimeOut", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a969c52e3b4011e05d33bf95f4035a5ba", null ],
    [ "ResultSetType", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a20f37658bb98643b426f7d7f2e440ccb", null ],
    [ "TransactionIsolation", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#ac92e8f3d99b02aa161d980ee61989889", null ],
    [ "TypeMap", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a2254afb5b7c7542ed4be824bf2daa647", null ],
    [ "URL", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#af82bacfe5b6faf0534ae06a9540cb886", null ],
    [ "User", "servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html#a9f8df451a16165b0cf243e37bf9c6b62", null ]
];
